@@ -27,12 +27,12 @@ def retry_rest_api(n: int = None, wait: int = 3):
                     k = 0
                 except HTTPError as e:
                     last_error = e
-                    if e.response and e.response not in RETRY_HTTP_CODES:
+                    if e.response and e.response.status_code not in RETRY_HTTP_CODES:
                         k = 0
                     else:
                         k -= 1
-                        if wait > 0:
-                            time.sleep(wait)
+                if k > 0 and wait > 0:
+                    time.sleep(wait)
             if last_error is not None:
                 raise last_error
 
